import time

import click
from ollama import ResponseError
from ollama import pull as pull_model

from . import PROJECT_VERSION
from .helpers import get_chat_response


@click.group()
@click.version_option(
    PROJECT_VERSION, "--version", "-v", message="RunLlama v%(version)s"
)
def runner():
    """Large language model runner"""
    pass


@runner.command()
@click.option(
    "--model", "-m", type=str, default="deepseek-r1:1.5b", help="Name of model"
)
@click.argument("prompt", type=str)
def query(model: str, prompt: str) -> None:
    """Query LLM"""

    try:
        response = get_chat_response(model, prompt)
    except ResponseError as e:
        click.echo(e)
        if e.status_code == 404:
            click.echo(f"Pulling model [{model}]...")
            pull_model(model)  # Pulls model from registry
            time.sleep(5)
            try:
                response = get_chat_response(model, prompt)
            except ResponseError as e:
                click.echo(e)
                click.echo("Exiting...")
                exit(1)
    except Exception as e:
        click.echo(e)
        exit(1)

    click.echo(response["message"]["content"])


@runner.command()
@click.argument("model", type=str)
def pull(model: str):
    """Pull a model from registry"""
    try:
        click.echo(f"Pulling model: {model}")
        pull_model(model)
        click.echo("Model pulled successfully!")
    except Exception as e:
        click.echo(e)
        exit(1)


if __name__ == "__main__":
    runner()



from ollama import ChatResponse, chat


def get_chat_response(model: str, prompt: str) -> ChatResponse:
    """Returns chat response."""
    return chat(
        model=model,
        messages=[
            {
                "role": "user",
                "content": prompt,
            },
        ],
    )



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['src']

package_data = \
{'': ['*']}

install_requires = \
['click==8.1.8', 'ollama==0.4.7']

entry_points = \
{'console_scripts': ['runllama = src.main:runner']}

setup_kwargs = {
    'name': 'runllama',
    'version': '0.1.0',
    'description': 'Simple CLI runner for Ollama (LLM) models',
    'long_description': '# RunLlama\n\nSimple CLI tool for [Ollama (LLM) models](https://ollama.com/search).\n\n## Installation\n\nInstall via pip:\n\n```bash\npip install runllama\n```\n\nOr with Poetry:\n\n```bash\npoetry add runllama\n```\n\nRun the CLI:\n\n```bash\nrunllama --help\n```\n\n## For Development\n\nBuild and run ollama server docker container\n\n```bash\ndocker build -t runllama .\ndocker run -d -p 11434:11434 -v ollama:/app/.ollama --name runllama runllama \n```\n\nInstall dependencies\n\n```bash\npoetry install\npoetry shell\n```\n\nRun Python script\n\n```bash\npython src/main.py --help\n```\n\n## License\n\nThe extension source code is licensed under the MIT License (see [LICENSE](LICENSE)).\n',
    'author': 'Manasseh',
    'author_email': 'believemanasseh@gmail.com',
    'maintainer': 'None',
    'maintainer_email': 'None',
    'url': 'None',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'entry_points': entry_points,
    'python_requires': '>=3.10,<4.0',
}


setup(**setup_kwargs)
